@@ -44,7 +44,7 @@ SCM robot_grab (void);
 SCM robot_zap (void);
 SCM robot_stop (void);
 
-SCM robot_get_sheilds (void);
+SCM robot_get_shields (void);
 SCM robot_get_energy (void);
 SCM robot_get_score (void);
 
