@@ -533,9 +533,9 @@ robot_stop (void)
 }
 
 SCM
-robot_get_sheilds (void)
+robot_get_shields (void)
 {
-  /* Returns the robot sheilds */
+  /* Returns the robot shields */
   return (gh_long2scm (robot_energy));
 }
 
