@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.4 1998/09/27 04:47:08 jhall Exp $ */
+/* $Id: main.c,v 1.7 1999/01/19 00:02:13 jhall Exp $ */
 
 /* GNU Robots game engine.  This is the main() program, using GNU
    Guile as my backend to handle the language. */
@@ -42,9 +42,9 @@
 #define MAP_YSIZE 20
 
 #define DEFAULT_ENERGY 1000
-#define DEFAULT_SHEILDS 100
+#define DEFAULT_SHIELDS 100
 
-#define VERSION   "GNU Robots, version 0.90"
+#define VERSION   "GNU Robots, version 0.91"
 #define COPYRIGHT "Copyright (C) 1998 Jim Hall, jhall1@isd.net"
 
 
@@ -60,7 +60,7 @@ int robot_dir = 0;
 
 long robot_score = 0;		/* the robot score, etc. */
 long robot_energy = DEFAULT_ENERGY;
-long robot_shields = DEFAULT_SHEILDS;
+long robot_shields = DEFAULT_SHIELDS;
 
 
 /* The program starts here */
@@ -81,7 +81,7 @@ main (int argc, char *argv[])
     {"version", 0, NULL, 'V'},
     {"help", 0, NULL, 'h'},
     {"map-file", 1, NULL, 'f'},
-    {"sheilds", 1, NULL, 's'},
+    {"shields", 1, NULL, 's'},
     {"energy", 1, NULL, 'e'},
     {NULL, 0, NULL, 0}};
 
@@ -111,7 +111,7 @@ main (int argc, char *argv[])
 	  break;
 
 	case 's':
-	  /* Set sheilds */
+	  /* Set shields */
 
 	  robot_shields = (long) atol (optarg);
 	  break;
@@ -185,7 +185,7 @@ main_prog (int argc, char *argv[])
   gh_new_procedure0_0 ("robot-grab", robot_grab);
   gh_new_procedure0_0 ("robot-zap", robot_zap);
 
-  gh_new_procedure0_0 ("robot-get-sheilds", robot_get_sheilds);
+  gh_new_procedure0_0 ("robot-get-shields", robot_get_shields);
   gh_new_procedure0_0 ("robot-get-energy", robot_get_energy);
   gh_new_procedure0_0 ("robot-get-score", robot_get_score);
 
@@ -208,7 +208,7 @@ main_prog (int argc, char *argv[])
       map[j] = malloc (ncols * sizeof (int));
     }
 
-  printf ("Loading map..\n");
+  printf ("Loading map %s\n", map_file);
   load_map (map_file, map, nrows, ncols);
   cleanup_map (map, nrows, ncols);
 
@@ -221,7 +221,7 @@ main_prog (int argc, char *argv[])
 
   /* draw the map */
 
-  printf ("Starting robot..\n");
+  printf ("Starting robot %s\n", robot_program);
   hook_init ();
   draw_map (map, nrows, ncols);
 
@@ -263,7 +263,7 @@ exit_nicely (void)
   /* Show statistics */
 
   printf ("\n------------------------ Statistics ------------------------\n");
-  printf ("Sheilds: %ld\n", (robot_shields < 0 ? 0 : robot_shields));
+  printf ("Shields: %ld\n", (robot_shields < 0 ? 0 : robot_shields));
   printf ("Energy: %ld\n", (robot_energy < 0 ? 0 : robot_energy));
   printf ("Score: %ld\n", robot_score);
 
@@ -294,7 +294,7 @@ usage (void)
   printf ("little robot, then watch him explore a world.\n\n");
 
   printf ("  -f, --map-file=FILE    load this map file\n");
-  printf ("  -s, --sheilds=N        set initial sheilds to N\n");
+  printf ("  -s, --shields=N        set initial shields to N\n");
   printf ("  -e, --energy=N         set initial energy to N\n");
   printf ("  -V, --version          output version information and exit\n");
   printf ("  -h, --help             display this help and exit\n");
