@@ -9,7 +9,7 @@
 
 ;;; grab all prizes
 (define (grab-all-prizes)
-  (while (eqv? (feel-prize) #t) (grab-prize))
+  (do () ((not (eqv? (feel-prize) #t))) (grab-prize))
 )
 
 ;;; grab a single prize
